#
# spec file for package cinnamon
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define __requires_exclude typelib\\((Cinnamon|St)\\)
%define __provides_exclude typelib\\(.*\\)
%define _name   Cinnamon
%define _version 3.6.0
Name:           cinnamon
Version:        3.6.7
Release:        lp150.2.6
Summary:        GNU/Linux Desktop featuring a traditional layout
License:        GPL-2.0+ AND LGPL-2.1
Group:          System/GUI/Other
Url:            https://github.com/linuxmint/Cinnamon
Source:         https://github.com/linuxmint/%{_name}/archive/%{version}.tar.gz#/%{_name}-%{version}.tar.gz
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source1:        README.Gsettings-overrides
# PATCH-FIX-OPENSUSE cinnamon-wheel-and-sbin-path sor.alexei@meowr.ru -- Make full sbin paths and use wheel as a sudo group.
Patch0:         %{name}-wheel-and-sbin-path.patch
# PATCH-FIX-UPSTREAM cinnamon-network-user-connections.patch joss@debian.org -- Do not ask password everytime for wireless networks at login.
Patch1:         %{name}-network-user-connections.patch
# PATCH-FIX-OPENSUSE cinnamon-settings-native.patch sor.alexei@meowr.ru -- Remove foreign configuration tools and add openSUSE's native.
Patch2:         %{name}-settings-native.patch
# PATCH-FIX-OPENSUSE cinnamon-settings-xscreensaver-path.patch boo#960165 sor.alexei@meowr.ru -- Fix xscreensaver configs path.
Patch3:         %{name}-settings-xscreensaver-path.patch
# PATCH-FIX-OPENSUSE cinnamon-no-gksu-requirement.patch sor.alexei@meowr.ru -- Don't require gksu.
Patch4:         %{name}-no-gksu-requirement.patch
# PATCH-FEATURE-OPENSUSE cinnamon-favourite-applications.patch sor.alexei@meowr.ru -- Remove mintinstall from favourites and add YaST.
Patch5:         %{name}-favourite-applications.patch
# PATCH-FIX-OPENSUSE cinnamon-fix-typelib-false-positive.patch sor.alexei@meowr.ru -- Avoid any false positives in typelib detection.
Patch6:         %{name}-fix-typelib-false-positive.patch
# PATCH-FEATURE-OPENSUSE cinnamon-fallback-icewm.patch sor.alexei@meowr.ru -- Use IceWM as fallback.
Patch7:         %{name}-fallback-icewm.patch
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
# For gnome-background-properties.
BuildRequires:  desktop-data-openSUSE-extra
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gtk-doc
# For distributor.svg.
BuildRequires:  hicolor-icon-theme-branding-openSUSE
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cinnamon-desktop) >= %{_version}
BuildRequires:  pkgconfig(cjs-1.0)
BuildRequires:  pkgconfig(gnome-bluetooth-1.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(libcinnamon-menu-3.0)
BuildRequires:  pkgconfig(libcroco-0.6)
BuildRequires:  pkgconfig(libmuffin) >= %{_version}
BuildRequires:  pkgconfig(libnm-glib)
BuildRequires:  pkgconfig(libnm-util)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(polkit-agent-1)
Requires:       %{name}-gschemas = %{version}
Requires:       adwaita-icon-theme
Requires:       cinnamon-control-center-common >= %{_version}
Requires:       cinnamon-screensaver >= %{_version}
Requires:       cinnamon-session >= %{_version}
Requires:       cinnamon-settings-daemon >= %{_version}
Requires:       cjs >= %{_version}
Requires:       cups-pk-helper
Requires:       dbus-1-python
Requires:       dbus-1-python3
Requires:       gettext-runtime
Requires:       glib2-tools
Requires:       iso-country-flags-png
Requires:       libcinnamon-desktop-data >= %{_version}
# gkbd-capplet / gkbd-keyboard-display.
Requires:       libgnomekbd
Requires:       muffin >= %{_version}
Requires:       nemo
Requires:       pkgconfig
Requires:       polkit-gnome
Requires:       python3-gobject
Requires:       v4l-tools
Requires:       wget
Requires:       xdg-utils
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-lang
Recommends:     blueberry
Recommends:     cinnamon-themes
Recommends:     gnome-terminal
Recommends:     gnome-themes-standard
Recommends:     icewm
# cinnamon-2d was last used in openSUSE 13.2.
Provides:       %{name}-2d = %{version}
Obsoletes:      %{name}-2d < %{version}
# cinnamon-menu-editor was last used in openSUSE 13.2.
Provides:       %{name}-menu-editor = %{version}
Obsoletes:      %{name}-menu-editor < %{version}
# cinnamon-settings was last used in openSUSE 13.2.
Provides:       %{name}-settings = %{version}
Obsoletes:      %{name}-settings < %{version}
# typelib-1_0-Cinnamon-0_1 was last used in openSUSE Leap 42.1.
Provides:       typelib-1_0-Cinnamon-0_1 = %{version}
Obsoletes:      typelib-1_0-Cinnamon-0_1 < %{version}
%if 0%{?suse_version} > 1320
BuildRequires:  python2-devel
Requires:       python2-Pillow
Requires:       python2-cairo
Requires:       python2-gobject
Requires:       python2-gobject-cairo
Requires:       python2-pexpect
Requires:       python2-pyinotify
Requires:       python2-python-pam
%else
BuildRequires:  python-devel
Requires:       python-Pillow
Requires:       python-cairo
Requires:       python-gobject
Requires:       python-gobject-cairo
Requires:       python-pam
Requires:       python-pexpect
Requires:       python-pyinotify
%endif
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
Requires:       python3-gobject-Gdk
%if 0%{?suse_version} > 1320
Requires:       python2-gobject-Gdk
%else
Requires:       python-gobject-Gdk
%endif
%endif
%if 0%{?suse_version} > 1320
Requires:       NetworkManager-applet
%else
Requires:       NetworkManager-gnome
%endif

%description
Cinnamon is a modern Linux desktop which provides advanced innovative
features and a traditional user experience. It's easy to use,
powerful and flexible.

%package gschemas
Summary:        GNU/Linux Desktop featuring a traditional layout -- GSchemas
Group:          System/Libraries
Requires:       %{name}-gschemas-branding = %{version}
%glib2_gsettings_schema_requires

%description gschemas
This package provides GSettings schemas for
Cinnamon Desktop Environment.

%package gschemas-branding-upstream
Summary:        Upstream definitions of default settings and applications
Group:          System/Libraries
Requires:       %{name}-gschemas = %{version}
Requires:       libgnomesu
Supplements:    packageand(%{name}-gschemas:branding-upstream)
Conflicts:      otherproviders(%{name}-gschemas-branding)
Provides:       %{name}-gschemas-branding = %{version}
# cinnamon-branding-upstream was last used in openSUSE Leap 42.2.
Provides:       %{name}-branding-upstream = %{version}
Obsoletes:      %{name}-branding-upstream < %{version}
BuildArch:      noarch
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.Gsettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description gschemas-branding-upstream
This package provides upstream defaults for settings stored with
GSettings and applications used by the MIME system.

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
cp -a %{SOURCE1} .

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-schemas-compile \
  --enable-gtk-doc          \
  --with-ca-certificates=%{_sysconfdir}/ssl/ca-bundle.pem
make %{?_smp_mflags} V=1

%install
%make_install

# Non-executable in /usr/bin/ is unacceptable.
chmod a+x %{buildroot}%{_bindir}/%{name}-file-dialog

# We should own this directory.
mkdir -p %{buildroot}%{_libdir}/%{name}/extensions/

# Provide all GNOME compatible backgrounds (including openSUSE branding) to Cinnamon.
ln -s gnome-background-properties \
  %{buildroot}%{_datadir}/cinnamon-background-properties

dirname $(find %{buildroot}%{_datadir} -type f -name '*.py') | sort -u | while read dir; do
    # Compile Python bytecode.
    %py_compile .
done

mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop \
  %{buildroot}%{_datadir}/xsessions/default.desktop

find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}/

%suse_update_desktop_file %{name}-settings
%suse_update_desktop_file %{name}-settings-users
%suse_update_desktop_file %{name}-menu-editor
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}2d.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}-killer-daemon.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/%{name}.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/%{name}2d.desktop

%post
/sbin/ldconfig
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/%{name}.desktop 20
%if 0%{?suse_version} <= 1320
%desktop_database_post
%icon_theme_cache_post
%endif

%postun
/sbin/ldconfig
if [ ! -f %{_datadir}/xsessions/%{name}.desktop ]; then
    %{_sbindir}/update-alternatives --remove default-xsession.desktop \
      %{_datadir}/xsessions/%{name}.desktop
fi
%if 0%{?suse_version} <= 1320
%desktop_database_postun
%icon_theme_cache_postun
%endif

%if 0%{?suse_version} <= 1320
%post gschemas
%glib2_gsettings_schema_post

%postun gschemas
%glib2_gsettings_schema_postun
%endif

%files
%doc AUTHORS COPYING README.rst debian/changelog
%dir %{_sysconfdir}/xdg/menus/
%config %{_sysconfdir}/xdg/menus/%{name}-applications.menu
%config %{_sysconfdir}/xdg/menus/%{name}-applications-merged
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%{_bindir}/%{name}*
%{_bindir}/xlet-settings
%{_libexecdir}/%{name}*/
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/extensions/
# Note the requirements exclude list above.
%{_libdir}/%{name}/Cinnamon-0.1.typelib
%{_libdir}/%{name}/St-1.0.typelib
%{_datadir}/%{name}/
%{_datadir}/%{name}-background-properties
%exclude %{_datadir}/%{name}/theme/menu*.svg
%{_datadir}/%{name}-session/
%{_datadir}/xsessions/*.desktop
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/cinnamon-*.*
%{_datadir}/icons/hicolor/*/*/cs-*.*
%{_datadir}/icons/hicolor/*/*/pan-*.*
%{_datadir}/icons/hicolor/*/actions/*-lock-*.*
%{_datadir}/icons/hicolor/*/actions/list-edit-*.*
%{_datadir}/icons/hicolor/*/devices/audio-*.*
%{_datadir}/icons/hicolor/*/devices/bluetooth.*
%{_datadir}/icons/hicolor/*/devices/cpu*.*
%{_mandir}/man?/*%{name}*.?%{?ext_man}
%{_datadir}/dbus-1/services/org.Cinnamon.*.service
%{_datadir}/polkit-1/actions/org.cinnamon.settings-users.policy
%dir %{_datadir}/desktop-directories/
%{_datadir}/desktop-directories/%{name}-*.directory
%{_datadir}/gtk-doc/*

%files gschemas
%{_datadir}/glib-2.0/schemas/org.cinnamon.gschema.xml

%files gschemas-branding-upstream
%doc README.Gsettings-overrides
%{_datadir}/%{name}/theme/menu*.svg

%changelog
* Sat Feb  3 2018 sb56637@geckolinux.github.io
- Changed dependency from python-pam to python2-python-pam
* Sun Dec 24 2017 sor.alexei@meowr.ru
- Update to version 3.6.7:
  * Online Accounts: Use translations.
  * cinnamonDBus.js: Have GetMonitors throw an error back to GDBus
    if something goes wrong.
  * menu-applet: Rework vectorBox.
  * Fix power applet spamming the log file with error messages on
    laptops (gh#linuxmint/Cinnamon#7114).
  * Spices description: Do not cut off the letter "n".
  * Xlets: Fix shown info for overwritten xlets.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 3.6.6:
  * Sound settings: Assign the selected device to the profile
    selector.
* Tue Nov 21 2017 sor.alexei@meowr.ru
- Update to version 3.6.5 (changes since 3.6.3):
  * calendar applet: Just listen to the gsetting key for 24h to
    make sure the vertical panel default clock obeys global
    date/time settings.
  * st-theme.c: st_theme_resolve_url could assert with a theme
    issue.
  * cinnamon-settings: Use icon buttons in the xlet management
    pages.
  * Fixes crash if device.get_icon_name() is Null.
  * Allow showing seconds on a vertical panel.
  * cs_sound.py: Replace tabs with spaces.
  * calendar applet: Fix formatting.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 3.6.3:
  * Show-desktop: Disable peek-at-desktop by default.
  * menu applet: Recalculate applications list box height when the
    menu's allocation changes.
  * Applets: When setting an icon, make sure it's actually an
    St.Icon. Some applets (such as the keyboard applet) set
    _applet_icon to something other than an St.Icon, so it causes
    an error when trying to set the icon using one of the api
    functions. This was causing the keyboard applet not to show in
    the panel edit mode after a keyboard layout was added and
    removed.
  * applet settings: Fix panel switch buttons not being hidden when
    there is only one panel.
  * Add Adwaita-dark thumbnails.
  * extension settings: Scan the system directory for extensions.
  * Initialise applet position to avoid drag and drop errors in
    edit mode occasionally the null applet position was being
    carried through to the writing of the new applet causing
    apparent drop failures, and to the disappearance of the
    highlighted drop box. Much visible weirdness with a very simple
    solution.
  * workspace switcher: Fix an undeclared variable warning.
  * applet settings: Improve the logic for highlighting the panel.
    The panel is now only highlighted when there is more than one
    panel, and it's better about selecting and highlighting the
    correct panel when one is added or removed.
  * Fixed spacing. Add a missing semicolon.
  * popupMenu: Prevent a warning of this._triangle.
  * Clock applet: Respect a 12h/24h choice in the vertical mode.
* Sun Nov 12 2017 sor.alexei@meowr.ru
- Update to version 3.6.2:
  * st-texture-cache: Avoid potential null pointer dereference.
- Rebase cinnamon-no-gksu-requirement.patch.
* Thu Nov  9 2017 sor.alexei@meowr.ru
- Update to version 3.6.1:
  * Fix blurry and off-centred arrow in pop up submenus.
  * cinnamon-settings: Remove an ui file that is no longer used
    since the extension-settings-rework.
  * Spices.py: Fix xlets not installing if a file without an
    extension is in the po directory.
  * TreeListWidgets.py: Edit elements with double click.
  * Fix Gtk-Message when running a dialogue.
  * window-list: Account for hidden items during DnD repositioning.
  * Spices: Don't fail if the spice directory is missing.
- Rebase cinnamon-wheel-and-sbin-path.patch.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.0:
  * See /usr/share/doc/packages/cinnamon/changelog
- Rebase cinnamon-network-user-connections.patch,
  cinnamon-settings-native.patch, cinnamon-no-gksu-requirement.patch.
* Sun Aug 20 2017 sor.alexei@meowr.ru
- Update to version 3.4.6 (changes since 3.4.4):
  * osdWindow.js: Always check the theme node on first showing - an
    actor's width isn't necessarily filled if it hasn't been
    explicitly set, causing the first few activations of the OSD to not show an accurate level bar.
  * cs_default: Fix an incorrect button label (but preserve
    translations).
  * main.js: Remove an obsolete Meta enum member reference.
  * workspace.js: Use our normal prototype init method.
  * workspace.js: Initalise WindowClone._zoomStep to 0.
  * slideshow-applet: Fix a translation.
  * cs_themes.py: Create the file "~/.icons/default/index.theme" and
    set the selected cursor theme inside of it. This ensures other
    (non-gtk) applications end up using the same theme (though they
    are required to be restarted for these changes to take effect).
  * keyboard-applet: Applet icon vanishes when moved in edit mode.
  * cinnamon-json-makepot: Add keyword option, change language used
    by xgettext to JavaScript.
  * expoThumbnail: Correct a couple of calls with mismatched
    argument counts.
  * window-list: Set AppMenuButtons unreactive during panel edit
    mode.
  * panel-launchers: Set PanelAppLaunchers unreactive during panel
    edit mode.
  * windows-quick-list: Fix argument warning.
  * Fix a reference to undefined actor._delegate warning.
  * ui/environment: Handle undefined actors in
    containerClass.prototype.add.
  * ui/cinnamonDBus: Handle null xlet objects in
    CinnamonDBus.highlightXlet.
  * deskletManager: Initialise some variables and remove the
    variables that were initialised, probable typo
* Wed Jul 12 2017 sor.alexei@meowr.ru
- Require NetworkManager-gnome on openSUSE older than Leap 15.x
  still (boo#1047540).
* Sun Jul  9 2017 sor.alexei@meowr.ru
- Update to version 3.4.4:
  * classicSwitcher.js: Fix hidpi issues.
  * KeybindingWidgets.py: Fix parsing of accelerators that are
    shifted but not alpha-numeric characters.
  * xlet-settings.py: Do not crash when an invalid xlet id is
    provided.
  * window-list applet: Fix argument warning.
  * Add an issue template.
  * ui/settings: Handle undefined old settings values.
  * hotCorner.js: Fix hover delay callback.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 3.4.3:
  * panel-launchers: Put individual launcher actions back in the
    main popup, having an options and preferences submenu was a
    bit ambiguous.
  * panel-launchers: Remove an undeclared variable warning.
  * deskletManager: Correct a call to file.delete.
  * Add a menu item to toggle the on-screen keyboard.
- Use update-alternatives to create the default.desktop xsession.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 3.4.2:
  * st-texture-cache.c: Do not cache st_texture_cache_load_from_raw.
    Its only user is the Notification Daemon. These are transient
    images that were being stored in the cache that would never be
    evicted during theme changes (this does not just mean times
    when the user changed the icon theme).
  * l10n: Translate hardcoded string for settings reset
    confirmation dialogue.
  * Silence a few more warnings, new warnings.
  * expo, overview: Unreference actors that we destroy whenever the
    respective view closes.
  * cinnamon-slideshow.py: Only allow a single instance to run.
  * Sound applet: Avoid spacing problem in vertical panel.
  * photoframe-desklet: Fix a few issues.
  * notificationDaemon.js: Silence an occasional warning.
  * SettingsWidgets.py: Make switch widgets use "center" vertical
    alignment instead of "fill," to prevent the switch growing in
    height when the label text gets ellipsised (either through
    resizing of the window, or localisation).
  * Progress bar text initialises and resets.
  * cinnamon-settings-users: Restrict the size of user images, as
    they are displayed in the right view when a user is selected.
    If the image at /var/lib/AccountsService/icons/<user> is set to
    a ridiculously-sized image, it won't break the ui.
  * cs_user: Don't let large images break the ui - make sure we
    scale the selected image to an appropriate size.
    Also, don't crop user-selected images (but keep cropping webcam
    images) - it's strange to select an image file and have the
    ends of it cut off.
  * cinnamon-settings-users.py: Fix picture preview in file
    selector to maintain a reasonable size.
  * cs_user.py: Handle image previews better in the face chooser
    dialogue.
  * ChooserButtonWidgets.py: Fix a Python 3 error.
  * window-list: Bring space around preview down and correct a
    calculation problem.
  * StScrollView: Queue redraws whenever the adjustments change, to
    prevent artifacts outside of the view itself.
  * StScrollView: More effective way of fixing the graphical
    artefacts generated during scrolling. This also appears to fix
    some unrelated tearing issues I was seeing in the menu while
    testing.
  * main.c: Own onboard's dbus name to prevent it starting when
    gnome's a11y keyboard settings key is active
    (org.gnome.desktop.a11y.applications screen-keyboard-enabled).
    Also own caribou's daemon. Caribou's OSK won't interfere in a
    Cinnamon session, but its daemon will run needlessly in the
    background otherwise.
  * panel: Avoid cjs giving a warning that dummyPanels[i][j] is
    undefined.
  * systray applet: Make sure an icon actually got parented to
    this.manager_container before calling remove_child.
    This issue can occur during session startup.
  * spacer applet: Use a unique style class in the theme to prevent
    the applet from appearing active when hovered.
  * theme: Add applet-spacer class for spacer applet.
  * spacer applet: Use track_hover instead of a new style to
    prevent highlighting.
  * osdWindow: get the correct child allocation when calculating
    the width of the level bar. If a padding or margin is added to
    the level-bar style class, it was causing the parent bin to
    expand to accomodate the child's width plus its required
    padding.
- Rebase cinnamon-wheel-and-sbin-path.patch,
  cinnamon-no-gksu-requirement.patch,
  cinnamon-favourite-applications.patch.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 3.4.1:
  * Remove usage of GTK_POLICY_EXTERNAL.
  * checkBox.js: Remove extra unused argument which was causing a
    warning with new cjs/mozjs.
  * st-bin.c: Fix y_fill setter (it was setting x_fill to the value
    of the existing y_fill, before it is set in the same call).
  * menu applet: Fix keyboard navigation of recent context menu.
    Fix closing of same menu when switching to another category.
    Also fix closing when opening another recent's context menu.
  * menu applet: Notify when a recent file is activated that can't
    be accessed.
  * menu applet: Make missing file notification transient.
  * menu applet (vector box): Partially revert c0d37dd: there is
    flickering as events go from a button to the vector box and
    back. Remove the idle callback, and directly react to the enter
    even once more. To compensate, increase our
    maybeUpdateVectorBox delay timeout, which more or less fixes
    the original problem the above commit was attempting to fix.
  * menu applet: _select_category - only call displayButtons if the
    category has really changed.
  * menu applet: Fix keyboard navigation when a second recent
    context menu is toggled open.
  * Sound settings: Fix device icons.
  * xlet-settings.py: Ignore files and directories in the config
    directory that aren't created by our settings api as well as
    instances that no longer exist.
  * ExtensionCore.py: Don't scrub the config directory on load.
    This is no longer necessary since xlet settings now ignores
    anything that isn't an active instance, and some applets need a
    place to store extra files so they get cleaned up on uninstall.
  * cs_panel.py: Fix a crash when there are no panels.
  * sound-applet: Remove extraneous arguments on add_actor calls.
  * radioButton.js: Remove an extra argument to add_actor.
  * window-list-applet: Fix undefined reference warning.
  * cinnamon-json-makepot: Add support to extract "title" and
    "units" keys on list elements.
  * User applet: Remove the ability to switch to guest with LightDM.
  * runDialog.js: Fix undefined variable warning.
  * Reorganise the default applets in the panel.
  * User applet: Remove trailing spaces.
  * Applets: Make TextIconApplet smarter and adapt to vertical
    panels.
  * menu applet: Use _select_category to select recents and places,
    so we can cache the current selection more accurately and
    prevent needless calls to _displayButtons.
  * window list: Add a missing dependency to settings.
- Remove cinnamon-fix-gtk-3.14.patch.
- Rebase cinnamon-no-gksu-requirement.patch.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * Fix gnome terminal losing desktop file association during
    Cinnamon restart.
  * cinnamon-json-makepot: Add support to scan for JS files inside
    sub-dirs.
  * Start systray applet first
  * Use generic marshaller.
  * Pull functions out of loops in _refreshPlaces, _refreshApps...
  * Move uri assignment in _refreshRecent's while loop into new...
  * Use let instead of var in new handler functions.
  * panel: Rework allocation logic to avoid looping in edit mode
    this was causing the context menu animation to fail to complete
    causing the user not to be able to exit edit mode.
  * theme-node: Fix leak on stylesheet change.
  * cinnamon_dbus_acquire_name: Don't leak the result.
  * cinnamon_dbus_acquire_name: Don't leak error.
  * keyboard: Destroy the key's boxpointe.
  * Fix hotcorner hover delay timeout removal. This fixes a
    "Invalid or null source id used when attempting to run
    Mainloop.source_remove()" when leaving a hotcorner. The timeout
    is already destroyed by returning false in the callback, but we
    still knew about the timeout id and tried to remove the
    non-existing timeout.
  * st-box-layout: Don't report a paint volume when we have no
    allocation.
  * window-tracker: Fix a memory leak.
  * tooltips.js: Remove leftover logging.
  * Add cinnamon-stap-monitor utility.
  * panel.js: Couple fixes to previous commit. Let the panel
    sections cover the entire panel in edit mode. Clean up
    _allocate a bit - since we always have the centre zone occupied
    (artificially or naturally,) we don't ever need to handle cases
    where it isn't.
  * panel.js: Fix dnd pseudo-class style application for vertical
    panels.
  * panel: Allow right and left panel zones to naturally fill space.
    Fix vertical allocate calculations in st-box-layout (align_end
    was only working for horizontal box layouts).
  * panel.js: Clean actor and style class names up, simplify some
    code that no longer needs to differentiate between vertical and
    horizontal panels.
  * cs_screensaver.py: Expose setting for floating widgets.
  * panel.js: Restore the "important" style flag, accidentally
    removed from panel zones.
  * expoThumbnail.js: Don't reposition thumbnails on
    position-changed.
  * cs_screensaver.py: Use a stack to switch between default
    screensaver and plugin previews.
  * panel.js: Restore some allocation code mistakenly removed in a
    previous commit. This restores the behavior of allowing
    left/right panels to occupy more than half the panel if the
    centre zone is empty.
  * Sound applet: Fix a segmentation fault that happened when menu
    animations were disabled (gh#linuxmint/Cinnamon#5977).
  * cinnamon-desktop-editor: Use the default icon when file is
    nonexistent.
  * st-theme-node: Improve error reporting.
  * St: Support CSS margin property.
  * Fix cursor black background when taking screenshot.
  * JS API misc/util.js: Add spawnCommandLineAsync.
  * recent-applet: Fix wrong menu placement.
  * Cinnamon Tutorial: Add instructions for xlet l10n.
  * windowManager: Move handling of workspace switch effects to one
    place.
  * window-list: Don't lose our focus style class when opening the
    context menu.
  * Settings widgets range: Add an optional argument to show the
    current value of on the scale widget. This was originally the
    way it worked in the xlet settings, but with the rework, that
    functionality wasn't reimplemented. This rendered the settings
    of several applets less usefull.
  * Show desktop applet: Fix preview being stuck by
    keyboard-triggered menu open.
  * settings.js: Rebuild the settings file if it becomes corrupted.
    If the settings have already been loaded, we use the latest
    version we have, otherwise we restore from defaults.
  * vertical-panels: Make proper calculations for panel intellihide.
  * Keyboard applet: Always show something in panel edit mode.
  * Power applet: Always show something in panel edit mode
  * JS API util.js: Add doNotReap parameter to trySpawn ct. itzexor
  * util.js: Add documentation for spawn_async.
  * Add support to manage the systemd services available on the
    system.
  * cs_startup.py: Add a "Run now" button for when a row is selected.
  * Make sure applets that don't support vertical panels don't get
    dropped on a vertical panel. This was happening with at least
    some applets, causing them to "disappear", and could only be
    recovered by removing them from applet settings and re-adding
    them again.
  * cinnamon-settings: Fix some sliders being drawn backwards.
  * settings.js: Handle corrupt settings the right way. Fixes
    several issues with the previous implementation.
  * xlet settings: Add a list widget.
  * xlet settings: Fix the reference to new option added to wrong
    element.
  * Settings: Add support for lightdm-settings.
  * xlets-about-dialog: Show timestamp if exists else show version
    & show "more info" button.
  * spawn_async: Clean the callbacks up after we're done.
  * looking-glass: Use bracket notation for property accessors when
    inspecting.
  * Environment: Don't fail in toString().
  * looking-glass: Set null results' value to "[null]".
  * Fix panel timeout spinbuttons jumping around
    (gh#linuxmint/Cinnamon#6374).
  * Add Manjaro Support in System Info (gh#linuxmint/Cinnamon#6387).
  * systray: Add CSS class to permit theming.
  * systray-applet: Don't crash in on_applet_removed_from_panel.
  * st-theme-node: Remove a double declaration that gives a
    compiler warning.
  * Start inode/directory application instead unregistered
    x-scheme-handler/file in case of unmounted bookmarks.
  * st-entry: Change the variable type to avoid a compiler warning.
  * Add a chooser for "inode/directory" to be able to choose the
    default file manager.
  * xlet-settings: Add a missing string for l10n.
  * st-box-layout: Remove an unused variable.
  * panel.js: Refactor Panel._showPanel and Panel._hidePanel.
  * panel.js: Don't clip the panel box shadow when showing after
    hide.
  * cs_accessibility: Restore previous theme when disabling
    High Contrast.
  * Remove panelMenu.js, which is unused but for 2 applets.
    There are a bunch of applets that import it but don't use it,
    all of which can be fixed now.
  * hotcorners: Remove the icon option.
  * cinnamon-looking-glass.py: Handle the numpad entering in entry.
  * Remove aclocal from autogen.sh as autoreconf runs it.
  * Fix for non translated applet names on Remove context menu items.
  * [Xlets] Expose config deletion request to xlet.
  * modalDialog: Avoid a js warning.
  * utils: Add check-js, to scan for runtime-breaking javascript
    syntax errors.
  * Adjustments after enabling margin for st.
  * cs_user.py: Save appropriately sized .face for
    cinnamon-screensaver.
  * cs_mouse: Add new settings to control acceleration/sensitivity.
  * power-applet: Add support for warning and error style classes.
  * cs_panel.py: Rework individual panel page to simplify code, fix
    some bugy behaviour, and improve readability.
  * Update keybindings.js.
  * Adapt Cinnamon to multi-process CSD.
  * messageTray: Show critical notifications in fullscreen.
  * cs_panel.py: Replace panel widgets with backended ones.
    This will hopefully ensure that the widgets are consistent with
    the rest of Cinnamon in terms of behaviour and appearance, as
    well as easier to maintain.
  * panel.js: Keep track of panelPosition and monitor changes.
  * panel.js: Refactor _moveResizePanel.
  * layout.js: Don't include clipped off areas in input region.
  * README file to reStructuredText file.
  * St: Margin: Remove margin:auto from menu applet and default
    theme. This avoids warning messages as margin:auto is not
    supported. And it also means third party theme developers will
    not copy non-functional CSS. The warning messages for the
    programmatic insertion of margin:auto in the menu applet were
    particularly cryptic.
  * st: Fix a couple icon/text-shadow bugs.
  * cinnamon-json-makepot: Fix for undefined global name.
  * Update cs_power.py.
  * Use St.Icon instead of fetching icons from St.TextureCache.
  * all: Adapt to changes for the new cjs (gjs 1.48/mozjs38).
  * panel.js warning fix.
  * osdWindow: Fix the level bar display.
  * Remove memory info stuff from looking glass, cinnamon-global.
  * control: Adjust version reqs for libcjs.
  * all: Some additional warning fixes due to gjs 1.48.0->1.48.2
    changes.
  * panel-launchers: Fix the panel launcher animation.
  * melange: don't freeze on quit with custom log watchers.
  * desklet.js: Ignore an extra argument to setContent().
  * js/ui/tooltip.js: Check if this.mousePosition is defined.
  * Move this.mousePosition initial assignment to TooltipBase.
  * Supress CJS mozjs38 warnings in applet, dbusMenu, indicator...
  * Correct indentation.
  * main.js: Improve logging of GLib.Errors and objects
    (gh#linuxmint/Cinnamon#6486).
  * menu-applet & panel-launchers: Add new mouse cursors while.
    dragging applications (gh#linuxmint/Cinnamon#5859)
  * l10n: Update POT file.
  * l10n: Generate additional files.
- Rebase cinnamon-settings-native.patch.
- Add cinnamon-fix-gtk-3.14.patch: Add GTK+ 3.14 compatibility.
* Thu Jan 26 2017 sor.alexei@meowr.ru
- Fix password changing in cinnamon-wheel-and-sbin-path.patch.
* Sun Jan  8 2017 sor.alexei@meowr.ru
- Update to version 3.2.8:
  * menu applet: Only construct one context menu for recent files,
    and re-use it.
  * menu applet: Don't reconstruct recent files, just re-order,
    add, remove as required.
  * menu applet: Fix a couple of minor leaks (actors created but
    never added to a container - being GInitiallyUnowned, they
    never get their floating ref sunk, and so can't be unreffed.
    Fix a prototype mismatch, and just rename GenericButton to
    NoRecentDocsButton, since that's the only user of it.
  * Fix tuples for Python 3.6.
  * tooltips.js: Add a hide timer to check if a tooltip should hide
    itself, but for various reasons never got to act on a
    leave-event (due to vagaries in event reporting).
  * recent applet: Rework to be non-destructive when updating the
    recent list (this brings a lot of the recent changes to the
    menu applet over to this one).
  * recents, applets: Couple of warning clean ups.
  * network applet: Remove a useless log warning. At some point
    more than a year ago we started getting these (possibly a
    change to NetworkManager), they have no value whatsoever, but
    fill up the log.
- Rebase cinnamon-network-user-connections.patch,
  cinnamon-no-gksu-requirement.patch.
* Fri Dec 23 2016 sor.alexei@meowr.ru
- Update to version 3.2.7:
  * cinnamon-settings: Do a better job of handling long labels.
  * Update polling frequency to make the mouse tracking smoother.
  * Layout: Ignore NaN numbers when updating regions.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 3.2.6:
  * See /usr/share/doc/packages/cinnamon/changelog
- Rebase cinnamon-settings-xscreensaver-path.patch,
  cinnamon-no-gksu-requirement.patch, cinnamon-fallback-icewm.patch.
* Thu Nov 24 2016 sor.alexei@meowr.ru
- Update to version 3.2.2:
  * build: Make AX_ macros optional.
  * [Xlet settings] Fix for icon choosers stuck dialogues.
  * [cinnamon-json-makepot] Add support for "title" key.
  * Ensure a default icon size of 16px if the icon-size is not set
    in the indicator icon theme class.
  * [workspace-switcher] Fix buttons' size Buttons didn't get
    proper height (or width in vertical mode) if the auto-scale
    font setting was not enabled.
  * Restore the ability to theme the menu applet menu separately
    from other menus.
  * cs_effects: Disable menu animations when turning of window
    effects.
  * [applet.js] Re add ability to display a separator on applets
    context menus.
  * [applet.js] Add a mechanism to highlight applets with open
    menus.
  * [menu-applet] Fix keynav issues with TAB and right.
  * Use the Gio library for establish the file permissions in
    replace of the spawnCommandLine usage.
  * panel-launchers: Close the menu before destroying when removing
    a launcher.
  * [Xlet settings] Add a translation mechanism to xlets settings
    windows.
  * cs_backgrounds.py: Fix thumb generation on Debian Jessie.
  * [sound-applet] Remove a show percentage label for slider option.
  * theme: Fix theming of the workspace switcher.
- Rebase cinnamon-no-gksu-requirement.patch.
- Remove cinnamon-optional-ax-macros.patch: fixed upstream.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.1:
  * See /usr/share/doc/packages/cinnamon/changelog
- Rebase ../cinnamon-wheel-and-sbin-path.patch,
  cinnamon-settings-native.patch,
  cinnamon-settings-xscreensaver-path.patch,
  cinnamon-no-gksu-requirement.patch, cinnamon-fallback-icewm.patch.
- Add cinnamon-fix-typelib-false-positive.patch: Avoid any false
  positives in typelib detection.
- Add cinnamon-optional-ax-macros.patch: Make AX_ macros optional
  (commit 023c17f).
- Remove requirements in cinnamon-branding-upstream that belong in
  libcinnamon-desktop-branding-upstream.
- Replace cinnamon-branding with cinnamon-gschemas-branding:
  gschemas can be installed standalone from the main cinnamon
  package yet still have to be branded.
* Fri Jul 15 2016 sor.alexei@meowr.ru
- Update to version 3.0.7:
  * Fix power settings segfault.
* Thu Jun 23 2016 sor.alexei@meowr.ru
- Update to version 3.0.6:
  * Add a generic "bluetooth" icon.
  * power applet: Don't connect to any signals that call
    _devicesChanged until we have the power proxy (since the
    callbacks assume we do have it).
  * windowAttentionHandler.js: Make the ignored application check
    case- insensitive. While we're here make it a gsettings array
    for convenience.
  * org.cinnamon.gschema.in: Add pidgin to ignored wm classes.
  * Touchpad settings: Invert motion-threshold setting widget.
  * appletManager.js: Fix copy/pasting applet panel applet layouts.
    Extension.get_max_instances() needed an extra argument, and
    then we were doing work twice - finished removing obsolete code.
  * cinnamon-recorder: Fix crash when starting recorder.
  * cinnamon-recorder.c: Restore avoidance of the panel when
    drawing the recording indicators. This was removed during some
    panel work a while back and never restored. Always draw them on
    the primary monitor now (the only monitor with reliable,
    simple-to-get workarea information).
  * Fix spelling mistakes.
  * onscreen keyboard: Add option to change activation behaviour -
    accessible mode has the keyboard appear whenever focus demands
    it (ordinary accessibility behavior). On-demand mode will have
    the keyboard only appear when the user requests it via an
    applet click or keyboard shortcut.
  * Themes settings: Fix loading icon themes when a theme isn't
    readable.
  * popupMenu.js: Use the signalManager.disconnect correctly -
    the source actor (the panel actor for the applet) has to be the
    second argument, the object to disconnect from. Was causing
    flickering in the menu applet after repositioning it.
  * Settings: Don't hardcode "more info" link colour in spices
    modules.
  * [desrt] network: Properly remove connections from list.
  * Network applet: Fix icon not showing VPN status.
  * Network applet: Delete trailing spaces.
  * Network applet: Fix applet showing "Auto" wireless connection
    when turning wifi OFF and then back ON.
  * tray icons: Bump icon request to 24px, then scale back to 20px
    in the applet. This is needed due to changes to GtkIconSize
    values in Gtk3. GtkStatusIcon iterates thru the built-in icon
    sizes to pick an appropriate icon to use, and as of 3.18 there
    are no sizes between 16px and 24px.
  * Preferred application settings: Set mimetypes more exhaustively.
- Rebase cinnamon-network-user-connections.patch.
* Wed Jun  1 2016 sor.alexei@meowr.ru
- Update to version 3.0.5:
  * cinnamon-settings: Remove hard-coded theming for the main
    cinnamon-settings icon view.
  * Background settings: Apply EXIF rotations to thumbnails.
  * cinnamon-util.c: cinnamon_util_get_icon_for_uri.c – use a
    custom icon if one is set in metadata (via file manager).
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 3.0.4:
  * Update pot file.
  * cs_effects: Only show overlay scrollbar toggle when using
    gtk3 >= 3.16.
  * sound applet: Use an icon that actually exists for blank
    coverart.
  * sound-applet: Fix an icon name.
  * Ignore accents/stokes when searching the menu or
    cinnamon-settings.
  * Menu applet: Remove trailing spaces.
  * Menu applet: Don't refresh twice at the same time.
  * [Menu applet] Fix not cleared drag placeholder in favourites
    box, if an application was dragged over, but not dropped on the
    favourites box.
- Rebase cinnamon-settings-native.patch,
  cinnamon-no-gksu-requirement.patch.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 3.0.3:
  * Ensure label text is properly escaped before applying it with
    set_markup().
  * SettingsWidgets.py: Use a more compatible GFileMonitorFlags –
    WATCH_MOVES is not available in glib 2.40.
  * cinnamon-settings: Include module keywords in desktop files.
  * cinnamon-app: Provide access to desktop file keywords.
    Use them in the menu applet search.
  * generated desktop files: Re-run, to remove unnecessary comment.
  * extensions: Check extensions for unsafe calls (synchronous,
    etc., things that can potentially freeze Cinnamon) and make the
    user aware of them in Cinnamon Settings.
  * ExtensionCore.py: scan_extension_thread – if the metadata.json
    file is not found, this must be a versioned xlet, check the
    parent directory for it instead.
  * cs_power.py: Expose setting to allow lid-closed action even
    when external monitors are attached.
  * messageTray.js: Don't let notifications with buttons fade on
    mouse-over.
  * menu applet: Use application id instead of application name for
    searches prevents duplicate search results for applications
    with the same desktop entry name when searching with a more
    specific term.
  * sound applet: smplayer: Fix artist metadata display and disable
    seek. While seeking does work, after the first time you seek
    the amount seeked is incorrect. It appears to seek the amount
    between the beginning of the seek bar and where you released
    the click instead.
  * cs_themes: Add setting for dark theme variant preference.
    This is only settable from ~/.config/gtk-3.0/settings.ini, so
    add the ability to modify that as well.
  * cs_effects.py: Expose gtk-overlay-scrollbar setting.
  * cs_sound: Set selection mode to none on the SoundBox() object.
  * Settings: Don't include text/html in the source code mimetypes.
  * st-texture-cache.c: use g_themed_icon_new instead of
    g_themed_icon_new_with_default_fallbacks.
* Thu May 12 2016 sor.alexei@meowr.ru
- Update to version 3.0.2:
  * Cache generated thumbnails.
  * Fix desktop effects on dialogs and menus.
    This prevents desktop effects on dialogs and menus from being
    used if desktop-effects is turned off. It's like already like
    this in the effects settings dialog.
  * Power applet: Fixed declaration of alias variable.
  * Window list: Fix call on null object.
  * Fix handling of device icon where GIcon is null.
  * cinnamon-settings: Don't set the stack switcher to use the main
    settings stack on creation.
    This is causing visual glitches in a lot of Gtk themes when
    changing from the main icon view to a page that displays the
    stack switcher.
  * Fix highlighting not working correctly for multiple instances
    of an applet.
  * ExtensionCore.py: Don't break when an xlet provides a bad icon
    file.
  * Add null conditional to return empty array when get_devices
    returns null.
  * Correct a potential infinite loop.
  * accessibility settings: Don't use PackageKit for now when
    looking for assistance applications that are installed.
    Just look for their binaries, and notify if not installed.
    Watch the bin folders in case the user installs the dependency
    and doesn't restart cinnamon settings.
  * cs_sound.py: Add a close button to the speaker test dialog.
  * Fix image close crash.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency (boo#978298).
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * extensions: Fix the alignment of the rating number in the
    "Get more" pages so it won't get covered by overlay scrollbars.
  * Bump Muffin version requirement because of API changes.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * Add option to show/hide favbox in menu applet.
  * Add new default application buttons.
  * Show panel-launchers actions.
  * Tab indents into space indents, more item without dots.
  * Move sound settings to python as a native module.
  * Add a custom page to display when no input devices are
    available or applications are currently playing. Add a custom
    settings box for the sound effects page to prevent getting a
    very tall window when opening the settings. Make a few tweaks
    to the test sound dialog and add the relevant icons.
  * Some visual tweaks to the sound settings.
  * Sound settings: Add mute to all volume controls.
  * cs_sound.py: Few fixes to the volume slider/mute button.
  * layout.js: Remove code for interaction with the screensaver.
  * cs_sound.py: Add padding to the end of stream names in
    applications page.
  * Viber stealing focus fix.
  * magnifier.js: Update the lens size as well as shape when we turn
    on lens mode.
  * Generate new desktop files for sound and accessibility.
  * Touchpad settings: Rename "natural scrolling" to
    "reverse scrolling direction".
  * Fix middle click action in the photo frame.
  * photoframe: Recurse subdirectories.
  * Sound settings: Fix device not showing when its icon isn't
    found (fixes bluetooth devices not showing up).
  * Power settings: Don't add the Gtk.Stack if it's empty.
  * Power settings/applet: Let the user rename battery powered
    devices.
  * Power settings: Fix power bars not being aligned.
  * tooltips.js: Hide if the stage's key focus changes - prevents
    tooltips from becoming stuck if you use the keyboard to switch
    focus (hit the menu key while a window list preview is showing).
  * cs_keyboard: Add a "wide" style class to the pane separator in
    the shortcuts page and remove some unneeded padding so this
    looks a little nicer in most newer themes.
  * effects: Enable effects on dialogs and menus by default.
  * Sound applet: Correctly identify changed artwork from Spotify
    (and add support for new URLs in version 0.27.x).
  * Theme settings: Don't filter themes missing gtk-3.0 if they
    provide gtk-3.*.
  * Show multi line descriptions in applet about.
  * Sound applet: Use wget to download remote artwork covers.
  * layout: Tweak the handling of menus in the top_window_group to
    match muffin changes.
  * Cinnamon Settings: Fixed gi.require_version() warnings.
  * Cinnamon Settings: Remove a couple of old debug output.
  * Cinnamon Settings: Retire cinnamon-bluetooth
    (replaced with Blueberry).
  * Revert "St-texture-cache: Don't monitor file changes (should
    increase performance, might cause regressions in cases where the
    St texture needs to be refreshed following a file change)".
  * panel-launcher: Fix an undeclared variable warning.
  * Fixed cinnamon slideshow error.
  * Adjust to Muffin API changes for handling fullscreen windows.
  * Extensions: Fix the "Disable all extensions" not working.
  * Update generated files.
  * Update pot file.
- Remove cinnamon-fix-backgrounds-lookup.patch,
  cinnamon-icon-themes-with-cursors.patch: merged upstream.
- Rebase cinnamon-settings-native.patch,
  cinnamon-no-gksu-requirement.patch,
  cinnamon-favourite-applications.patch.
* Wed Mar 30 2016 sor.alexei@meowr.ru
- Update to version 2.8.8:
  * layout.js: Remove code for interaction with the screensaver.
    It was always broken until 2.8.7, where it was 'fixed', and has
    caused some reported regression where the panels will be hidden
    after returning from the screensaver.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 2.8.7:
  * cs_keyboard.py: Fix event handlers for teaching keybindings -
    the cursor-down and -up keys were being incorrectly used to
    navigate the tree view during teach mode, and it was breaking
    focus (and cancelling the teach).
  * magnifier: Limit max zoom to a reasonable value.
  * menu applet: Fix vfade in the program list - it was only showing
    when desktop zoom was turned entirely off.
    We've reworked zoom since then, so that the .applications key
    only determines whether we listen to key and mouse bindings or
    not - actual zoom activation occurs only when the magnification
    factor becomes > 1.0.
  * screensaver: Fix proxy to listen to the correct service, fix
    layout changes when the screensaver starts/stops.
  * layout.js: Get an actual boolean from the screensaver proxy.
  * signalManager.js: Pass argument array correctly, and don't wipe
    out this._storage when filtering out disconnected items.
  * cinnamonDBus: Rename Cinnamon to CinnamonDBus, and import
    Cinnamon so screenshot calls work.
  * window-list: Prevent the window list thumbnails from showing
    when the applets context menu is open.
  * window-list: Properly update the label in the window preview.
  * cs_backgrounds: For an update of some of the reveal children
    on initial page load to fix some settings not showing properly
  * Fix D-Bus methods for screen capture.
  * util.js: Do not modify error message.
- Rebase cinnamon-fix-backgrounds-lookup.patch,
  cinnamon-favourite-applications.patch.
* Thu Dec 24 2015 sor.alexei@meowr.ru
- Add cinnamon-settings-xscreensaver-path.patch: fix
  xscreensaver configs path (boo#960165).
* Mon Dec 21 2015 sor.alexei@meowr.ru
- Exclude typelib(Cinnamon), typelib(CinnamonJS), typelib(Gvc),
  and typelib(St) from dependencies and provides as these are in a
  custom directory: /usr/lib64/cinnamon/ (last two also conflict
  with GNOME Shell package).
- Merge typelib-1_0-Cinnamon-0_1 into cinnamon as it doesn't
  contain real GObject introspection (different directory).
* Sun Dec 13 2015 sor.alexei@meowr.ru
- Depend on cinnamon-control-center-common: required by parts of
  cinnamon-settings.
- Fix cinnamon-icon-themes-with-cursors.patch: was discarding
  icons without icon cache (boo#958881).
* Fri Nov 27 2015 sor.alexei@meowr.ru
- Update to 2.8.6:
  * Make launcher-editor and directory-editor resizable.
  * window-list: Properly scale the window previews for hidpi.
  * popupmenu.js: Fix documentation.
- Separate GSettings schemas to cinnamon-gschemas package.
- Add cinnamon-fallback-icewm.patch: use IceWM as fallback.
* Fri Nov 20 2015 sor.alexei@meowr.ru
- Update to 2.8.5:
  * workspace-switcher applet: Update relevant workspace graph when
    a window is added or removed from a workspace.
  * workspace-switcher applet: Do not ignore maximised windows in
    the graph.
  * Handle situations when /usr/lib64/ is a symlink to /usr/lib/
    and vice versa on some distributions causing modules being
    loaded multiple times.
  * Replace has_icon method with lookup_icon one to fix missing
    flags icons in keyboard applet.
  * signalManager.js: Fix typo.
  * effects: Currently when setting the minimise animation to
    "traditional" no sound effect is used when restoring the window.
    Change this so the minimise sound is played in this case.
  * Sound applet: Close menu when closing media player.
  * Fix menu applet's graphical oddity during search.
* Thu Nov 12 2015 sor.alexei@meowr.ru
- Update to 2.8.4:
  * Fix a timer issue in TooltipBase and window list; in rare cases,
    two enter events occurred without a leave event in between,
    leaving an orphaned _showTimer behind.
  * Sound applet: Fetch the status of Loop and Shuffle at the
    beginning, not just on update.
  * Fix user_data not passing to callback.
  * js/ui/keybindings.js: Remove idle function for media keys.
    This is implemented in muffin now, for *all* muffin-managed
    keybindings.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 2.8.3:
  * layout.js: Rework our strut handling code to better handle
    multi-monitor situations.
  * effects: Set the default settings to actually match the default
    "Cinnamon" style so these get used on new installs.
  * desklet/boxpoiner: Don't try to correct the arrow side for the
    desklet menu inside desklet.js. The boxpointer handles this on
    it's own.
  * CinnamonWindowTracker: Pull some upstream fixes so Chromium
    apps will use the proper icons in the window list.
  * Fix allocation error when STBoxLayout is align_end.
  * Sound applet: Fixed huge icons/artwork in HiDPI.
  * Keyboard settings: Release grab when focus is lost.
  * attentionhandler suppress autofocus.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 2.8.2:
  * Replaced uses of the commands module with subprocess.
  * st-container.c: Fix dispose method causing crashes.
    priv->children was being updated during destruction of each
    child, causing invalid pointers when iterating thru
    priv->children. Use clutter_actor_destroy_all_children to do
    just that, and we get no corruption.
  * appletManager.js: Fix get_object_for_uuid() when an empty index
    of appletObj is hit upon.
  * Settings: Added link to mintlocale's input method.
  * Update pot file.
- Rebase cinnamon-wheel-and-sbin-path and
  cinnamon-settings-native.patch.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 2.8.1:
  * panel.js: Factor out panel allocation code and prevent
    division-by-zero error.
  * workspace-switcher: Properly resize the switcher when using
    custom panel sizes.
  * Fix code execution by replacing os.system() w/ subprocess.call(),
    pep8 formatting.
  * Panel launchers applet: Syncronise with settings with correct
    variable caused issues when adding, moving or removing items.
  * capi.py: Handle the failure to locate c-c-c modules more
    gracefully.
  * capi.py: Fix x86-32 platform detection.
  * capi.py: Scan all relevant paths.
  * Remove unused files/generate_desktop_files file.
  * capi.py: Add support for /usr/lib64 (used in RPM distros).
  * Fix command injection, replaced deprecate calls to "commands"
    module with their subprocess replacements.
  * PEP8 formatting.
  * Add exception handler just in case.
  * Fix potential NameError.
- Remove cinnamon-fix-capi.patch: fixed upstream.
- Rebase cinnamon-fix-backgrounds-lookup.patch.
* Wed Oct 21 2015 sor.alexei@meowr.ru
- Update to 2.8.0.
- Use upstream dependency declarations.
- Create cinnamon-branding-upstream, depend on branding in general.
- Put menu icon into cinnamon-branding-upstream.
- Merge cinnamon-settings, cinnamon-menu-editor, and cinnamon-2d
  packages into cinnamon as upstream doesn't separate those.
- Remove cinnamon-2.6.7-sbin-lspci.patch.
- Add cinnamon-wheel-and-sbin-path.patch.
- Remove cinnamon-2.6.7-settings-apps-openSUSE.patch.
- Add cinnamon-settings-native.patch.
- Rebase and rename network-user-connections.patch to
  cinnamon-network-user-connections.patch.
- Add cinnamon-no-gksu-requirement.patch: do not require gksu.
- Add cinnamon-favourite-applications.patch: remove mintinstall
  from favourites and add YaST.
- Add cinnamon-fix-capi.patch instead of a broken regexp.
- Add cinnamon-icon-themes-with-cursors.patch.
- Add cinnamon-fix-backgrounds-lookup.patch: don't ignore
  backgrounds with specified size.
- Add cinnamon-background-properties symlink to GNOME ones.
* Tue Aug 11 2015 i@marguerite.su
- use openSUSE distributor icon for menu applet.
- add patch: network-user-connections.patch from debian,
  to avoid asking for Wi-Fi passwords every time on login.
- drop patch: cinnamon-2.4.3-silently-ignore-bluetooth-applet.patch
* Mon Aug 10 2015 i@marguerite.su
- don't need to fix rpath
  * we used chrpath/patchelf to remove runpath and add rpath,
    but patchelf has an unfixed serious bug that confuses strip,
    which will cause a "version glibc_2.2.5 not defined in file
    libc.so.6 with link time reference" segfault.
    https://github.com/NixOS/patchelf/issues/10
  * upstream borrowed this hacky patch from gnome-shell
    http://lists.opensuse.org/opensuse-commit/2012-05/msg00780.html
    that will link libcinnamon-js.so, so indeed no need of rpath fix
    anymore.
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.13
  * A11y applet: Show active keyboard modifiers when
    sticky keys are enabled
  * Renamed mintInstall.desktop -> mintinstall.desktop
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.7
- Adjusted sbin patch to work with 2.6.7
- Adjusted cinnamon-settings openSUSE patch to work with version 2.6.7
* Thu Apr 23 2015 stefan@fam-elser.de
- update version 2.4.8
* Wed Nov 19 2014 i@marguerite.su
- update version 2.4.3
  * Small l10n fixes, refreshed desktop files
  changes in 2.4.2
  * photoframe desklet: fix mega leak, don't cache all images,
    destroy old images
  * photoframe desklet: cancel the update timer when removing
    the desklet.
- cherry pick upstream commit
  * cinnamon-2.4.3-silently-ignore-bluetooth-applet.patch
  * xlets: silently ignore uninstalled items (like bluetooth)
  * close boo#906015
* Mon Nov 10 2014 i@marguerite.su
- update version 2.4.1
- dicouple cinnamon-bluetooth which doesn't work at all
  and its applet (bluetooth@cinnamon.org) keep requiring
  gnome-bluetooth 3.8, annoying when startup
  * users have bluetooth devices can use other gnome apps
* Sun Nov  9 2014 i@marguerite.su
- drop cinnamon-2.3.0-remove-bluetooth.patch
  * without this, package still build
- fix boo#904414: Cinnamon 2.4 Applets fail to load
  * /usr/bin/cinnamon has RUNPATH by default, but only
    RPATH can find /usr/lib(64)/cinnamon/libcinnamon-js.so
    have to explicitly set RPATH=/usr/lib(64)/cinnamon
  * we use chrpath/patchelf to delete RUNPATH and force
    set RPATH. As RUNPATH will "hide" RPATH and OBS may
    have DT_RUNPATH for all builds, we can never set
    RPATH by patch (the RPATH in Makefiles will end up
    to be RUNPATH anyway)
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * Touchpad: Added support for 2 and 3 finger clicks
  * Fix checkbox allocation
  * windownManager.js: compositor "destroy" events will
    be received for non-visible
  * cinnamon-settings windows: fix visibility of minimum
    opacity spinner.
  * fix some applets
- added cinnamon-2.3.0-remove-bluetooth.patch
  * remove bluetooth support
* Wed Jul  9 2014 stefan@fam-elser.de
- Update version 2.2.14
* Mon Jun  2 2014 stefan@fam-elser.de
- Added cinnamon-themes to the recommend packages
* Mon May 26 2014 stefan@fam-elser.de
- update version 2.2.13
* Wed May 21 2014 stefan@fam-elser.de
- update to version 2.2.10
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.9
* Fri May  2 2014 i@marguerite.su
- update version 2.2.4
* Sat Apr 19 2014 i@marguerite.su
- update version 2.2.3
* Thu Dec  5 2013 i@marguerite.su
- find a hard way to override "menu-icon".
* Thu Dec  5 2013 i@marguerite.su
- fix bnc#852432: Cinnamon network settings doesn't work
- fix other cinnamon-settings options, make them openSUSEish
  * add patch cinnamon-openSUSE.patch
  * replace those non-existent Mint stuff with YaST2.
* Wed Dec  4 2013 i@marguerite.su
- fix typo in the override file
- add a new requirement: patterns-openSUSE-cinnamon
* Tue Dec  3 2013 i@marguerite.su
- add more branding options.
* Tue Nov 26 2013 johann.luce@wanadoo.fr
- update version 2.0.14
  * cinnamon-settings defaults: show the current default in the list for media handling
  * Fix autoscroll not being disabled sometimes …
  * Restore bouncy effect to panel launchers applet
  * spices: fix update button not i18n'd.
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.13
  * Use St.Icon rather than textures in menu/applauncher/notifdaemon (fixes icons stuck on GNOME theme, and icons not refreshing with theme change)
  * Fixed power applet tooltip showing name for secondary batteries
  * Updated pot file
  * cinnamon-settings: l10n units in info module
  * Switched to double quotes for gettext, simplified info module, added support for LM info title
  * cinnamon-settings: l10n months names in calendar module
  * cinnamon-settings: Fixed timezone selection
  * Fix default applications pickers (audio, video, images) to set default for all related mimetypes they support
  * cinnamon-settings: spices: fix update button always showing, remove some logging
  * cinnamon-desktop-editor: add preview widget
  * cinnamon-settings: reign in extra wide icon spacing in some locales
  * Moved Account Details to Prefrences
  * user applet: align avatar left
  * Also fix the instance ID for expo and scale applets
  * Remove warning about a missing applet instance ID
* Tue Nov 12 2013 johann.luce@wanadoo.fr
- update version 2.0.12
  * If local settings aren't parseable, don't fail, overwrite them with the default
  * spices: Fix continuous updating of update button
* Fri Nov  8 2013 johann.luce@wanadoo.fr
- update version 2.0.11
  * Draw desktop background immediately.... duh
* Mon Nov  4 2013 johann.luce@wanadoo.fr
- update version 2.0.10
  * Impose max-width to recent buttons in menu
  * Merge branch 'speed' of https://github.com/linuxmint/Cinnamon into speed
  * upstream: recompute all nodes when theme changes
  * st-icon - recompute when icon theme changes
  * Some more optimization
  * menu: Realize labels immediately also
  * menu applet: Realize icons immediately
  * Some upstream improvements regarding theme caching. Seems to improve …
  * Fill callback in backgroundManager.js
- 2.0.9
  * Revert "Merge pull request #2516 from Rodsevich/master" …
  * cinnamon-settings: remove references to non-existant close button
  * Handle desktop entirely in cinnamon
  * menu: Realize labels immediately also
  * menu applet: Realize icons immediately
  * Some upstream improvements regarding theme caching. Seems to improve …
  * backgroundManager: check for existance of org.gnome.desktop.backgroun… …
  * cinnamon-settings - remove close progress button, and X button
  * notification applet: Allow scroll bar to be grabbed
  * Never scroll notification content, maintain size
* Sat Nov  2 2013 i@marguerite.su
- brandings are landing.
* Sat Nov  2 2013 i@marguerite.su
- add cinnamon-bluetooth to requirements, optional
* Sat Nov  2 2013 i@marguerite.su
- add cinnamon-control-center to requirements, or it will crash
* Sat Nov  2 2013 i@marguerite.su
- update version 2.0.8
  * some cleanup
* Fri Nov  1 2013 i@marguerite.su
- make cinnamon-settings compulsory, or you can't even set wallpaper.
- add cinnamon-2d to recommendations
* Fri Nov  1 2013 i@marguerite.su
- add cjs and cinnamon-settings-daemon to requirement
* Fri Nov  1 2013 i@marguerite.su
- %%desktop_database_post/postun need to be triggered on %%post/%%postun
  or gnome-shell/gdm will lost all its icons. mimetype database will
  break. don't know why because Cinnamon doesn't have any .desktop
  files with MimeType= defined. not suitable for this macro at all
- fix "no 'menu-icons' defined in org.cinnamon" warning.
* Wed Oct 30 2013 i@marguerite.su
- in openSUSE, we don't have gksu, we use gnomesu, so replace it
  in /usr/bin/cinnamon-settings-users
* Wed Oct 30 2013 i@marguerite.su
- in openSUSE, /sbin isn't in path. so cinnamon-settings can't find
  `lspci` to load its systeminfo module. fixed
- add patch: cinnamon-2.0.7-sbin-lspci.patch
* Wed Oct 30 2013 i@marguerite.su
- fix a basic path lookup error, now cinnamon-settings can use
  modules provided by libcinnamon-control-center1.
* Wed Oct 30 2013 i@marguerite.su
- add runtime dependency (python crap) for cinnamon-settings:
  * python-pexpect
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.7
  * too much, see below:
    https://github.com/linuxmint/Cinnamon/commits/master
* Mon Oct 21 2013 i@marguerite.su
- update version 2.0.3
  * see https://github.com/linuxmint/Cinnamon/commits/master
- cleanup work
- remove lang_package because now there's a cinnamon-translations package
- remove patch: %%{name}-power-12_1.patch, EOL
- remove patch: %%{name}-fix-session-file.patch, upstream changed
- add python module requires
- split typelib-1_0-Cinnamon-0_1 sub-package
* Wed Nov 14 2012 nmo.marques@gmail.com
- Update to version 1.6.7
  + fix advanced option in cinnamon-settings
  + change icon name in glade file
  + change the name of the panel launcher editor
  + other fixes and updated translations
- Add xz to BuildRequires and source in .xz now
- Sub packages menu-editor and settings are now 'noarch'; split
  lang package
* Fri Nov  9 2012 nmo.marques@gmail.com
- Update to version 1.6.6
  + Look in cinnamon's locale dir in main.c
* Mon Nov  5 2012 nmo.marques@gmail.com
- Update to version 1.6.5
  + Added ABI variable and some if's for gnome 3.4
  + Fix: Bluetooh shows off when actaully on.
- Add cinnamon-desktop-openSUSE.gschema.override: basic branding
  and tweaks though gsettings overrides
- Sub-package splitting: cinnamon-2d and cinnamon-settings
- Add dependency on faenza-icon-theme-mint
- Spec file rework
* Fri Oct 26 2012 nmo.marques@gmail.com
- Update to version 1.6.4
  + fix for menu applet when using a11y screen magnifier
* Sun Oct 21 2012 nmo.marques@gmail.com
- Update to version 1.6.3
  + use MODIFIER_TAP where allowed, otherwise use OTHER
  + fix bnc#781074 - previous was false positive on 1.6.2
  + minor fixes
* Fri Oct 19 2012 nmo.marques@gmail.com
- Update to version 1.6.2
  + Administration and preference don't appear in menu editor,
    fixes bnc#781074
  + Move up and Move down buttons don't work in menu editor (if
    Gnome 3 broke that we need to switch back to the GTK2 version
    of this tool, as on the original fork)
  + Don't hide spotify in systray
  + Conky/mintupload windows appear (careful not to hide gimp
    utility windows though or make it configurable)
  + workspaces can overlap in expo grid
  + recommend muffin
  + depend on gsjdbus
  + muffin should depend on libmuffin0 and gir-muffin of the same
    version (currently it's possible to upgrade cinnamon and
    libmuffin without upgrading other muffin packages and it
    results in crashes)
  + Alt-arrow shortcuts don't work in nemo
* Thu Sep 27 2012 nmo.marques@gmail.com
- Update to version 1.6.1
  + bug fix point release, no changelog available to public
* Tue Sep 18 2012 nmo.marques@gmail.com
- Update to version 1.6.0
  + new feature: workspace OSD
  + new feature: window quick list
  + new feature: notifications applet
  + ALT+TAB is now configurable
  + improved sound applet
  + more details: http://cinnamon.linuxmint.com/?p=207
- Add 'python-imaging' to Requires (cinnamon-settings)
* Mon Sep 10 2012 nmo.marques@gmail.com
- Update to version 1.5.8
  + minor spec changes, no impact (re-organize dependencies)
  + no changelog available
* Thu Sep  6 2012 nmo.marques@gmail.com
- Update to version 1.5.7
  + migrate to gsettings; removed gconf stuff
  + add 'python-lxml' to Requires
  + use %%suse_update_desktop_file on new cinnamon2d desktop files
  + add 'fdupes' to build requires - currently for man pages dups
  + minor improvements
* Sun Jun 17 2012 wr@rosenauer.org
- revert upstream changes for power management DBus interface
  to make battery monitoring work in power applet (for 12.1)
* Thu Jun  7 2012 nmo.marques@gmail.com
- Remove RPATH sed filtering to allow internal libraries to be
  properly loaded
* Tue May 15 2012 nmo.marques@gmail.com
- Update to 1.4.0-UP1
* Wed Mar 28 2012 nmo.marques@gmail.com
- Some nvidia drivers have issues if %%{_libdir} is in cinnamon
  binary RPATH. We remove %%{_libdir} RPATH and users are adviced
  to use nvidia driver .295 or superior, from .280 to .285 there
  are regressions and Cinnamon isn't working with it.
* Wed Mar 14 2012 nmo.marques@gmail.com
- Fix broken build, add sources.
* Tue Mar 13 2012 nmo.marques@gmail.com
- Update to version 1.4.0
  + major improvement and bug fixes
  + Adds menu editor based on alacarte.
- Add sub-package: cinnamon-menu-editor (Recommends).
- Merged lang package with main.
- Added 'gdm' to requires.
- Removed 'opensusify' patch. We have now the upstream 'Menu'
  button. Users can easilly customize in gsettings with upstream
  utility distributed with cinnamon.
- Minor spec improvements. Package cinnamon-settings no longer
  obsoletes itself.
* Mon Feb 20 2012 nmarques@fedoraproject.org
- Update to version 1.3.1
  + upstream bugfix release
- Add 'python-gconf' to Requires, needed by cinnamon-settings.
* Sat Feb 18 2012 nmo.marques@opensuse.org
- Update to version 1.3.0:
  - Applets Improvements
  - Settings Improvements
  - Menu Improvements
- Add gnome-common BuildRequires
- Remove cinnamon-fix-fsf-headers.patch: upstreamed
- Removed cinnamon-explicitly-link-againt-gl.patch: upstreamed
* Tue Feb  7 2012 nmarques@opensuse.org
- Add cinnamon-fix-fsf-headers.patch: Update the FSF address in
  several files headers. Submitted upstream:
  https://github.com/linuxmint/Cinnamon/pull/303
- Remove 'BuildRequires: gnome-common', not needed.
* Mon Feb  6 2012 nmarques@opensuse.org
- Add cinnamon-explicitly-link-againt-gl.patch: Cogl does not
  explicitly link against GL or GLES any more, and clutter master
  dropped the 'gl' pkg-config requirement because it introduced
  unneeded and conflicting dependencies. Cinnamon still uses
  glXQuery* API, so it needs to explicitly link against libGL.
  Upstream: https://github.com/linuxmint/Cinnamon/pull/301
- Removed dependency on gnome-shell -- though it's usefull, if a
  package requires cinnamon for build (ex: cinnamon-extensions),
  a lot of unwanted stuff is pulled.
* Sun Feb  5 2012 nmarques@opensuse.org
- Improved spec license texts.
* Sat Feb  4 2012 nmo.marques@gmail.com
- Add license for spec
* Thu Jan 26 2012 nmarques@opensuse.org
- Split browser plugins into 'cinnamon-browser-plugins' subpackage.
- Removed duplicated entries in %%files.
* Thu Jan 26 2012 nmarques@opensuse.org
- Add cinnamon-opensusify.patch: change default menu text from
  'Menu' to 'openSUSE' and default layout to 'classic'.
- Packaging:
  + Add conditionals to disable -Werror for >= 1220
  + Fixed gramatical errors on description and summaries
  + Added gnome-session-core to Requires.
  + Added muffin to Requires.
* Wed Jan 25 2012 nmarques@opensuse.org
- Add cinnamon-fix-session-file.patch: easy fix, gnome-shell puts
  file in different location.
* Tue Jan 24 2012 nmarques@opensuse.org
- Initial package
